<?php
/**
 * Functions File
 *
 * @package Amyra
 * @since 1.0
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Update theme default settings
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_default_settings() {

	$default_settings = array(		
									
                                    'menu_bar_bg_clr'                   => '#ffffff',
                                    'menu_bar_link_clr'                 => '#000000',
                                    'menu_bar_linkh_clr'                => '#FF6347',
                                    'continue_read_clr'                 => '#000000',
                                    'continue_read_hvr_clr'             => '#FF6347',
                                    'h1_clr'                       		=> '#000000',
                                    'h2_clr'                       		=> '#000000',
                                    'h3_clr'                       		=> '#000000',
                                    'h4_clr'                       		=> '#000000',
                                    'h5_clr'                       		=> '#000000',
                                    'h6_clr'                       		=> '#000000',
                                    'link_clr'                          => '#000000',
                                    'hover_link_clr'                    => '#FF6347',                                    
                                    'blog_layout'                       => 'grid',
                                    'blog_layout_grid'                  => 12,            
									'blog_excerpt_length'               => 40,
                                    'blog_show_date'                    => 1,
                                    'blog_show_author'                  => 1,
                                    'blog_show_cat'                     => 1,
                                    'blog_show_tags'                    => 1,
									'blog_show_comment'                 => 1,									
									'single_show_comment'               => 1,                                    
                                    'cat_layout'                        => 'grid',
                                    'cat_layout_grid'                   => 12,                                    
                                    'cat_show_date'                     => 1,
                                    'cat_show_author'                   => 1,
                                    'cat_show_cat'                      => 1,
                                    'cat_show_tags'                     => 1,
									'cat_show_comment'                  => 1, 
                                    'single_post_fet_img'               => 1,                                                                 
                                    'fc_post_layout'                    => '[fpc_post_block]',
                                    'show_fc_post_home'                 => 0,
                                    'show_fc_post_front'                => 0,
                                    'show_fc_post_search'               => 0,
                                    'show_fc_post_single'               => 0,
                                    'show_fc_post_cat'                  => 0, 										
                                    'header_social'                     => 0,
                                    'footer_social'                     => 0,
                                    'facebook'                          => '',
                                    'twitter'                           => '',
                                    'linkedin'                          => '',
                                    'behance'                           => '',
                                    'dribbble'                          => '',
                                    'instagram'                         => '',
                                    'youtube'                           => '',
                                    'pinterest'                         => '',
                                    'copyright'                         => __('&copy {year} Amyra WordPress Blog Theme', 'amyra'),                                   
                            );

	return apply_filters('amyra_options_default_values', $default_settings );
}

/**
 * Escape Tags & Slashes
 *
 * Handles escapping the slashes and tags
 *
 * @package Amyra
 * @since 1.0
 */
function amyra_esc_attr($data) {
    return esc_attr( $data );
}


/**
 * Function to excerpt length
 * 
 * @package Amyra
 * @since 1.0
 */
function iclean_excerpt_length( $length ) {
	$blog_excerpt_length 	= amyra_get_theme_mod( 'blog_excerpt_length' );
	return $blog_excerpt_length;
}
add_filter( 'excerpt_length', 'iclean_excerpt_length', 999 );

/**
 * Function to excerpt more
 * 
 * @package Amyra
 * @since 1.0
 */
function iclean_excerpt_more( $more ) {
    return '...';
}
add_filter('excerpt_more', 'iclean_excerpt_more');

/**
 * Function to add array after specific key
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_add_array(&$array, $value, $index, $from_last = false) {
	
	if( is_array($array) && is_array($value) ) {

		if( $from_last ) {
			$total_count 	= count($array);
			$index 			= (!empty($total_count) && ($total_count > $index)) ? ($total_count-$index): $index;
		}

		$split_arr 	= array_splice($array, max(0, $index));
    	$array 		= array_merge( $array, $value, $split_arr);
	}
	return $array;
}

/**
 * Function to get footer sidebar widget class
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_footer_widgets_cls( $sidebar_id ) {	
	global $_wp_sidebars_widgets;	
	
	$sidebars_widgets_count = $_wp_sidebars_widgets;

	if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) {

		$widget_count 	= count( $sidebars_widgets_count[ $sidebar_id ] );
		$widget_classes = 'widget-count-' . count( $sidebars_widgets_count[ $sidebar_id ] );

		if ( $widget_count == 2 ) {			
			$widget_classes .= ' amyra-col-6';
		} elseif  ( $widget_count == 3 ) {			
			$widget_classes .= ' amyra-col-4';
		} elseif ( $widget_count == 4 ) {			
			$widget_classes .= ' amyra-col-3';
		}  elseif ( $widget_count == 5 ) {			
			$widget_classes .= ' amyra-col-5c';
		}  elseif ( $widget_count == 6 ) {			
			$widget_classes .= ' amyra-col-2';
		} else {			
			$widget_classes .= ' amyra-col-12';
		}
		return $widget_classes;
	}
}

/**
 * Determine where to display featured content section
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_fcs_display() {

	global $wp_query;

	$display 	= false;
	$fp_is_home 	= amyra_get_theme_mod( 'show_fc_post_home' );
	$fp_is_frontp 	= amyra_get_theme_mod( 'show_fc_post_front' );	
	$fp_is_search 	= amyra_get_theme_mod( 'show_fc_post_search' );	
	$fp_is_single 	= amyra_get_theme_mod( 'show_fc_post_single' );
	$fp_is_cat 		= amyra_get_theme_mod( 'show_fc_post_cat' );
	$fp_is_news 	= amyra_get_theme_mod( 'show_fc_news_page' );

	if( is_search() && !empty($fp_is_search) ) {
		$display = true;
	} elseif( $wp_query->is_posts_page && !empty($fp_is_home) ) {
		$display = true;
	} elseif( is_front_page() && !empty($fp_is_frontp) && !is_page_template('page-templates/news-page.php') ){
		$display = true;
	} elseif( is_front_page() && !empty($fp_is_news) && is_page_template('page-templates/news-page.php') ) {
		$display = true;
	} elseif( !is_front_page() && is_home() && !$wp_query->is_posts_page && !empty($fp_is_home) ) { // If Front page is not set and latest post is being displayed
		$display = true;
	} elseif( get_query_var('cat') && !empty($fp_is_cat) ) { // If WordPress category page
		$display = true;
	} elseif( is_single() && !empty($fp_is_single) ) { // If WordPress single page
		$display = true;
	}

	return $display;
}

/**
 * Function to get comment count text
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_get_comments_number( $post_id = '', $hide_empty = false ) {

	$comment_text = '';

	if( !empty($post_id) ) {

		$comment_number = get_comments_number( $post_id );

		if ( $comment_number == 0 && empty($hide_empty) ) {
			$comment_text = __('0 Comments', 'amyra');
		} elseif ( $comment_number > 1 ) {
			$comment_text = $comment_number . __(' Comments', 'amyra');
		} elseif ( $comment_number == 1 ) {
			$comment_text = __('1 Comment', 'amyra');
		}
	}

	return $comment_text;
}


/**
 * Function to get post excerpt
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_get_post_excerpt( $post_id = null, $content = '', $word_length = '55', $more = '...' ) {

	$word_length = !empty($word_length) ? $word_length : '55';

	// If post id is passed
	if( !empty($post_id) ) {
		if (has_excerpt($post_id)) {
			$content = get_the_excerpt();
		} else {
			$content = !empty($content) ? $content : get_the_content();
		}
	}

	if( !empty($content) ) {
		$content = strip_shortcodes( $content ); // Strip shortcodes
		$content = wp_trim_words( $content, $word_length, $more );
	}

	return $content;
}
/**
 * Handles column if has thumb or post formate media
 *
 * @package Amyra
 * @since 1.0
 */

function amyra_grid_column_class() {

	$grid_class =   'amyra-col-12 amyra-content-full';

	if( has_post_thumbnail()){
    	$grid_class =   'amyra-col-6 amyra-content-right';
	}	

	return $grid_class;
}
/**
 * Strip Slashes From Array
 *
 * @package Amyra
 * @since 1.0
 */
function amyra_slashes_deep($data = array(), $flag = false) {
  
    if($flag != true) {
        $data = amyra_nohtml_kses($data);
    }
    $data = stripslashes_deep($data);
    return $data;
}


function amyra_nohtml_kses($data = array()) {
  
  if ( is_array($data) ) {
    
    $data = array_map('amyra_nohtml_kses', $data);
    
  } elseif ( is_string( $data ) ) {
    $data = trim( $data );
    $data = wp_filter_nohtml_kses($data);
  }
  
  return $data;
}

/**
 * Function to get customizer value
 *
 * @package Amyra
 * @since 1.0
 */
function amyra_get_theme_mod( $mod = '' ) {
	
	$default_settings 	= amyra_default_settings();
	$default_val 		= isset($default_settings[ $mod ]) ? $default_settings[ $mod ] : '';
    
        return get_theme_mod( $mod, $default_val );
}

/**
 * Clean variables using sanitize_text_field. Arrays are cleaned recursively.
 * Non-scalar values are ignored.
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_sanitize_clean( $var ) {
	if ( is_array( $var ) ) {
		return array_map( 'amyra_sanitize_clean', $var );
	} else {
		$data = is_scalar( $var ) ? sanitize_text_field( $var ) : $var;
		return wp_unslash($data);
	}
}

/**
 * Checkbox sanitization callback.
 */
function amyra_sanitize_checkbox( $checked ) {
	return ( ( !empty( $checked ) ) ? true : false );
}

/**
 * Select sanitization callback.
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_sanitize_select( $input, $setting ) {
	$input = sanitize_key( $input );
	$choices = $setting->manager->get_control( $setting->id )->choices;
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Sanitize URL
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_sanitize_url( $url ) {
	return esc_url_raw( trim($url) );
}


/**
 * Handles the footer copy right text
 *
 * @package Amyra
 * @since 1.0
 */
function amyra_footer_copyright() {
	
	$current_year = date( 'Y', current_time('timestamp') );
	$copyright_text = amyra_get_theme_mod( 'copyright' );
	$copyright_text = str_replace('{year}', $current_year, $copyright_text);

	return apply_filters( 'amyra_footer_copyright', $copyright_text);

}