<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Amyra
 */

/**
 * Auto add more links.
 *
 * @package Amyra
 * @since 1.0
 */
function amyra_content_more() {	
	/* translators: link read more. */
	$text = wp_kses_post( sprintf( esc_html__( 'Continue reading &#10142; %s', 'amyra' ), '<span class="screen-reader-text">' . get_the_title() . '</span>' ) );
	$more = sprintf( '<div class="link-more"><a href="%s#more-%d" class="more-link">%s</a></div>', esc_url( get_permalink() ), get_the_ID(), $text );

	return $more;
}
add_filter( 'the_content_more_link', 'amyra_content_more' );

/**
 * Auto add more links.
 * 
 * @package Amyra
 * @since 1.0
 */
function amyra_excerpt_more_link( $excerpt ) {
    $excerpt 	.= amyra_content_more();
    return $excerpt;
}
add_filter( 'the_excerpt', 'amyra_excerpt_more_link', 21 );

/**
 * Change the archive title for category page.
 *
 * @package Amyra
 * @since 1.0
 */
function amyra_category_title( $title ) {
	
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	}

	return $title;
}
add_filter( 'get_the_archive_title', 'amyra_category_title' );



/**
 * Prints HTML with meta information for the current post-date/time and categories, tags..
 */
function amyra_posted_on( $meta = array() ) {

        $default_meta = array(
                                    'post_date' => 1,
                                    'author' 	=> 1,
                                    'category' 	=> 1,
                                    'tag'		=> 1,
                                    'comment'	=> 1,
                            );
	if( !empty($meta) && is_array($meta) ) {
		foreach ($default_meta as $meta_key => $meta_val) {
			$val = in_array($meta_key, $meta) ? 1 : 0;

			$result_meta[$meta_key] = $val;
		}
	}

	$result_meta = !empty($result_meta) ? $result_meta : $default_meta;
	extract( $result_meta, EXTR_SKIP );

	if( is_home() || is_front_page() || is_search()) {

		$post_date 	= amyra_get_theme_mod( 'blog_show_date' );
		$author 	= amyra_get_theme_mod( 'blog_show_author' );
		$category 	= amyra_get_theme_mod( 'blog_show_cat' );
		$tag 		= amyra_get_theme_mod( 'blog_show_tags' );
		$blog_show_comment 	= amyra_get_theme_mod( 'blog_show_comment' );

		$post_date_above 	= amyra_get_theme_mod( 'blog_show_date_above' );
		$author_above 		= amyra_get_theme_mod( 'blog_show_author_above' );
		$category_above 	= amyra_get_theme_mod( 'blog_show_cat_above' );
		

	} elseif( is_category() || is_archive() || is_tag() || is_author() ) {

		$post_date 	= amyra_get_theme_mod( 'cat_show_date' );
		$author 	= amyra_get_theme_mod( 'cat_show_author' );
		$category 	= amyra_get_theme_mod( 'cat_show_cat' );
		$tag 		= amyra_get_theme_mod( 'cat_show_tags' );
		$blog_show_comment 	= amyra_get_theme_mod( 'cat_show_comment' );	

		$post_date_above 	= amyra_get_theme_mod( 'cat_show_date_above' );
		$author_above 		= amyra_get_theme_mod( 'cat_show_author_above' );
		$category_above 	= amyra_get_theme_mod( 'cat_show_cat_above' );

	}

	if( ($post_date && empty($post_date_above)) 
		|| ( $author && empty($author_above) ) 
		|| ( $category && empty($category_above) ) 
		|| ( $tag && 'post' === get_post_type() ) 
		|| ( !empty($blog_show_comment)) ){

		echo '<div class="entry-meta">';
	}

	// Post Date
	if( $post_date && empty($post_date_above)) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

		echo '<span class="posted-on"><i class="fa fa-clock-o"></i>' . $posted_on . '</span>'; // WPCS: XSS OK.
	}

	// Post Author
	if( $author && empty($author_above) ) {
                $byline = sprintf(
                        __( '%s', 'amyra' ),'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a></span>'
                );
                echo '<span class="byline"><i class="fa fa-user"></i>' . $byline . '</span>';
	}

	// Post Category
	if( $category && empty($category_above) ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'amyra' ) );
		if ( $categories_list ) {
			printf( '<span class="cat-links"><i class="fa fa-folder-open"></i><span class="screen-reader-text">%1$s </span>%2$s</span>', esc_html__( 'Categories', 'amyra' ), $categories_list ); // WPCS: XSS OK.
		}
	}

	// Hide category and tag text for pages.
	if ( $tag && 'post' === get_post_type() ) {

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'amyra' ) );
		if ( $tags_list ) {
			echo '<span class="tags-links"><i class="fa fa-tags"></i>' . $tags_list . '</span>'; // WPCS: XSS OK.
		}
	}
	

	if ( !empty($blog_show_comment) &&  !post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link"><i class="fa fa-comments-o"></i>';
		/* translators: %s: post title */
		comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'amyra' ), array(
			'span' => array(
				'class' => array(),
			),
		) ), get_the_title() ) );
		echo '</span>';
	}

	if( ($post_date && empty($post_date_above)) 
		|| ( $author && empty($author_above) ) 
		|| ( $category && empty($category_above) ) 
		|| ( $tag && 'post' === get_post_type() ) 
		|| ( !empty($blog_show_comment)) ){

	echo '</div>';
	}
}



/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function amyra_entry_footer() {
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'amyra' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}

/**
 * Change the tag could args
 *
 * @param array $args Widget parameters.
 *
 * @return mixed
 */
function amyra_tag_cloud_args( $args ) {
	$args['largest']  = 1; // Largest tag.
	$args['smallest'] = 1; // Smallest tag.
	$args['unit']     = 'em'; // Tag font unit.

	return $args;
}
add_filter( 'widget_tag_cloud_args', 'amyra_tag_cloud_args' );
